git remote set-url origin https://git.jetbrains.space/alasdairm/main/oldschool_management_tools.git

OK storing dates in json just plain sucks
So lets store the data as parquet.  In fact dump the whole calendar to parquet.  Then you can work out what is going on.
